==> rocomall-service-1.1.3-20160511.113338-22-sources.jar: com/rocoinfo/rocomall/entity/insurance/InsuranceInfo.java <==
package com.rocoinfo.rocomall.entity.insurance;


import com.rocoinfo.rocomall.entity.IdEntity;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.util.Date;
@XmlAccessorType(XmlAccessType.FIELD)
public class InsuranceInfo extends IdEntity {

    private Date time;


    private String openId;

    private String policyNumber;

    @XmlElement(name = "userID")
    private Integer userid;

    @XmlElement(name = "productID")
    private Integer productid;

    private Float sumAss;

    private Integer payPeriod;

    private Integer totalPremium;


    private String dateStart;

    private String dateEnd;


    private String datePay;

    private String payStatus;


    private Integer failCause;

    @XmlElement(name = "pHName")
    private String phname;

    @XmlElement(name = "pHIdNoType")
    private String phidnoType;

    @XmlElement(name = "pHIdNo")
    private String phIdno;

    @XmlElement(name = "pHSex")
    private String phsex;

    @XmlElement(name = "pHTel")
    private String phtel;

    @XmlElement(name = "pHBirth")
    private String phbirth;

    @XmlElement(name = "pHMail")
    private String phmail;

    @XmlElement(name = "pHAddr")
    private String phaddr;

    @XmlElement(name = "pHMobile")
    private Integer phmobile;


    private String name;

    @XmlElement(name = "idNoType")
    private String idnotype;

    @XmlElement(name = "idNo")
    private String idno;

    @XmlElement(name = "birthDt")
    private String birthdt;


    private String sex;

    private String mail;


    private String addr;


    private String tel;

    public Date getTime() {
        return time;
    }


    public void setTime(Date time) {
        this.time = time;
    }


    public String getOpenId() {
        return openId;
    }


    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getPolicyNumber() {
        return policyNumber;
    }

    public void setPolicyNumber(String policyNumber) {
        this.policyNumber = policyNumber;
    }

    public Integer getUserid() {
        return userid;
    }


    public void setUserid(Integer userid) {
        this.userid = userid;
    }


    public Integer getProductid() {
        return productid;
    }

    public void setProductid(Integer productid) {
        this.productid = productid;
    }

    public Float getSumAss() {
        return sumAss;
    }

    public void setSumAss(Float sumAss) {
        this.sumAss = sumAss;
    }


    public Integer getPayPeriod() {
        return payPeriod;
    }

    public void setPayPeriod(Integer payPeriod) {
        this.payPeriod = payPeriod;
    }

    public Integer getTotalPremium() {
        return totalPremium;
    }


    public void setTotalPremium(Integer totalPremium) {
        this.totalPremium = totalPremium;
    }

    public String getDateStart() {
        return dateStart;
    }

    public void setDateStart(String dateStart) {
        this.dateStart = dateStart;
    }


    public String getDateEnd() {
        return dateEnd;
    }


    public void setDateEnd(String dateEnd) {
        this.dateEnd = dateEnd;
    }

    public String getDatePay() {
        return datePay;
    }


    public void setDatePay(String datePay) {
        this.datePay = datePay;
    }

    public String getPayStatus() {
        return payStatus;
    }


    public void setPayStatus(String payStatus) {
        this.payStatus = payStatus;
    }

    public Integer getFailCause() {
        return failCause;
    }


    public void setFailCause(Integer failCause) {
        this.failCause = failCause;
    }


    public String getPhname() {
        return phname;
    }

    public void setPhname(String phname) {
        this.phname = phname;
    }


    public String getPhidnoType() {
        return phidnoType;
    }

    public void setPhidnoType(String phidnoType) {
        this.phidnoType = phidnoType;
    }

    public String getPhIdno() {
        return phIdno;
    }

    public void setPhIdno(String phIdno) {
        this.phIdno = phIdno;
    }


    public String getPhsex() {
        return phsex;
    }

    public void setPhsex(String phsex) {
        this.phsex = phsex;
    }

    public String getPhtel() {
        return phtel;
    }

    public void setPhtel(String phtel) {
        this.phtel = phtel;
    }

    public String getPhbirth() {
        return phbirth;
    }


    public void setPhbirth(String phbirth) {
        this.phbirth = phbirth;
    }

    public String getPhmail() {
        return phmail;
    }


    public void setPhmail(String phmail) {
        this.phmail = phmail;
    }


    public String getPhaddr() {
        return phaddr;
    }

    public void setPhaddr(String phaddr) {
        this.phaddr = phaddr;
    }

    public Integer getPhmobile() {
        return phmobile;
    }

    public void setPhmobile(Integer phmobile) {
        this.phmobile = phmobile;
    }


    public String getName() {
        return name;
    }


    public void setName(String name) {
        this.name = name;
    }

    public String getIdnotype() {
        return idnotype;
    }


    public void setIdnotype(String idnotype) {
        this.idnotype = idnotype;
    }


    public String getIdno() {
        return idno;
    }


    public void setIdno(String idno) {
        this.idno = idno;
    }

    public String getBirthdt() {
        return birthdt;
    }

    public void setBirthdt(String birthdt) {
        this.birthdt = birthdt;
    }

    public String getSex() {
        return sex;
    }


    public void setSex(String sex) {
        this.sex = sex;
    }

    public String getMail() {
        return mail;
    }

    public void setMail(String mail) {
        this.mail = mail;
    }

    public String getAddr() {
        return addr;
    }


    public void setAddr(String addr) {
        this.addr = addr;
    }


    public String getTel() {
        return tel;
    }


    public void setTel(String tel) {
        this.tel = tel;
    }
}

==> rocomall-service-1.1.3-20160517.080856-40-sources.jar: com/rocoinfo/rocomall/entity/insurance/InsuranceInfo.java <==
package com.rocoinfo.rocomall.entity.insurance;


import com.rocoinfo.rocomall.entity.IdEntity;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.util.Date;
@XmlAccessorType(XmlAccessType.FIELD)
public class InsuranceInfo extends IdEntity {

    private Date time;


    private String openId;

    private String policyNumber;

    @XmlElement(name = "userID")
    private String userid;

    @XmlElement(name = "productID")
    private Integer productid;

    private Float sumAss;

    private Integer payPeriod;

    private Integer totalPremium;


    private String dateStart;

    private String dateEnd;


    private String datePay;

    private String payStatus;


    private Integer failCause;

    @XmlElement(name = "pHName")
    private String phname;

    @XmlElement(name = "pHIdNoType")
    private String phidnoType;

    @XmlElement(name = "pHIdNo")
    private String phIdno;

    @XmlElement(name = "pHSex")
    private String phsex;

    @XmlElement(name = "pHTel")
    private String phtel;

    @XmlElement(name = "pHBirth")
    private String phbirth;

    @XmlElement(name = "pHMail")
    private String phmail;

    @XmlElement(name = "pHAddr")
    private String phaddr;

    @XmlElement(name = "pHMobile")
    private Integer phmobile;


    private String name;

    @XmlElement(name = "idNoType")
    private String idnotype;

    @XmlElement(name = "idNo")
    private String idno;

    @XmlElement(name = "birthDt")
    private String birthdt;


    private String sex;

    private String mail;


    private String addr;


    private String tel;

    public Date getTime() {
        return time;
    }


    public void setTime(Date time) {
        this.time = time;
    }


    public String getOpenId() {
        return openId;
    }


    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getPolicyNumber() {
        return policyNumber;
    }

    public void setPolicyNumber(String policyNumber) {
        this.policyNumber = policyNumber;
    }

    public String getUserid() {
        return userid;
    }


    public void setUserid(String userid) {
        this.userid = userid;
    }


    public Integer getProductid() {
        return productid;
    }

    public void setProductid(Integer productid) {
        this.productid = productid;
    }

    public Float getSumAss() {
        return sumAss;
    }

    public void setSumAss(Float sumAss) {
        this.sumAss = sumAss;
    }


    public Integer getPayPeriod() {
        return payPeriod;
    }

    public void setPayPeriod(Integer payPeriod) {
        this.payPeriod = payPeriod;
    }

    public Integer getTotalPremium() {
        return totalPremium;
    }


    public void setTotalPremium(Integer totalPremium) {
        this.totalPremium = totalPremium;
    }

    public String getDateStart() {
        return dateStart;
    }

    public void setDateStart(String dateStart) {
        this.dateStart = dateStart;
    }


    public String getDateEnd() {
        return dateEnd;
    }


    public void setDateEnd(String dateEnd) {
        this.dateEnd = dateEnd;
    }

    public String getDatePay() {
        return datePay;
    }


    public void setDatePay(String datePay) {
        this.datePay = datePay;
    }

    public String getPayStatus() {
        return payStatus;
    }


    public void setPayStatus(String payStatus) {
        this.payStatus = payStatus;
    }

    public Integer getFailCause() {
        return failCause;
    }


    public void setFailCause(Integer failCause) {
        this.failCause = failCause;
    }


    public String getPhname() {
        return phname;
    }

    public void setPhname(String phname) {
        this.phname = phname;
    }


    public String getPhidnoType() {
        return phidnoType;
    }

    public void setPhidnoType(String phidnoType) {
        this.phidnoType = phidnoType;
    }

    public String getPhIdno() {
        return phIdno;
    }

    public void setPhIdno(String phIdno) {
        this.phIdno = phIdno;
    }


    public String getPhsex() {
        return phsex;
    }

    public void setPhsex(String phsex) {
        this.phsex = phsex;
    }

    public String getPhtel() {
        return phtel;
    }

    public void setPhtel(String phtel) {
        this.phtel = phtel;
    }

    public String getPhbirth() {
        return phbirth;
    }


    public void setPhbirth(String phbirth) {
        this.phbirth = phbirth;
    }

    public String getPhmail() {
        return phmail;
    }


    public void setPhmail(String phmail) {
        this.phmail = phmail;
    }


    public String getPhaddr() {
        return phaddr;
    }

    public void setPhaddr(String phaddr) {
        this.phaddr = phaddr;
    }

    public Integer getPhmobile() {
        return phmobile;
    }

    public void setPhmobile(Integer phmobile) {
        this.phmobile = phmobile;
    }


    public String getName() {
        return name;
    }


    public void setName(String name) {
        this.name = name;
    }

    public String getIdnotype() {
        return idnotype;
    }


    public void setIdnotype(String idnotype) {
        this.idnotype = idnotype;
    }


    public String getIdno() {
        return idno;
    }


    public void setIdno(String idno) {
        this.idno = idno;
    }

    public String getBirthdt() {
        return birthdt;
    }

    public void setBirthdt(String birthdt) {
        this.birthdt = birthdt;
    }

    public String getSex() {
        return sex;
    }


    public void setSex(String sex) {
        this.sex = sex;
    }

    public String getMail() {
        return mail;
    }

    public void setMail(String mail) {
        this.mail = mail;
    }

    public String getAddr() {
        return addr;
    }


    public void setAddr(String addr) {
        this.addr = addr;
    }


    public String getTel() {
        return tel;
    }


    public void setTel(String tel) {
        this.tel = tel;
    }
}
